//*****************************************************************
/*
	VLibras: Automatic contents translator from Portuguese to LIBRAS

	Copyright (c) 2015 Gustavo Sobral, Erickson Silva, Leonardo Araújo
	VLibras-Core group at LAViD, Federal University of Paraiba
*/
//*****************************************************************

/**
 * \file pyTradutor.hpp
 * \authors Erickson Silva, Gustavo Sobral, Leonardo Araújo
 * \date Janeiro 2015
 */

#ifndef PYTRADUTOR_H
#define PYTRADUTOR_H

#include <Python.h>

/** \brief Classe para execução do Tradutor
 *
 * Essa classe permite a execução e comunição do Tradutor
 * (Português -> Glosa) do sistema escrito em Python
 * permitindo sua utilização numa aplicação C++.
 */
class PyTradutor
{
private:
	PyObject * pName;
	PyObject * pModule;
	PyObject * pDict;	
	PyObject * pFunc;
	PyObject * pArgs;
	PyObject * pResult;
public:
	
	/** \brief O construtor da classe
	 *
	 * O construtor inicia o ambiente Python para execução da tradução do tradutor.
	 */
	PyTradutor();

	/** \brief O destrutor da classe
	 *
	 * O Destrutor finaliza o ambiente Python montado para execução da tradução.
	 */
	~PyTradutor();

	/** \brief Converte Português para Glosa
	 *
	 * Converte a string de entrada em Português para Glosa 
	 * através da execução do Tradutor e retorna esse resultado 
	 *
	 * \param input Ponteiro para char com o texto de entrada em Portugês
	 * \return Ponteiro para char com a tradução da entrada em Glosa
	 */
	char * convertStringToGlosa(const char * input);
};

#endif /* PYTRADUTOR_H */